==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pl-PL/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategorie aktywów',
    'category_name'  					=> 'Nazwa kategorii',
    'checkin_email'                     => 'Wyślij e-mail do użytkownika przy odbiorze / przypisaniu.',
    'checkin_email_notification'        => 'Ten użytkownik otrzyma wiadomość e-mail o odbiorze / przypisaniu.',
    'clone'                             => 'Klonuj kategorię',
    'create'  							=> 'Stwórz Kategorię',
    'edit'                              => 'Edytuj Kategorię',
    'email_will_be_sent_due_to_global_eula' => 'Wiadomość e-mail zostanie wysłana do użytkownika, ponieważ jest używana licencja globalna.',
    'email_will_be_sent_due_to_category_eula' => 'Wiadomość e-mail zostanie wysłana do użytkownika, ponieważ dla tej kategorii jest ustawiona licencja.',
    'eula_text'							=> 'EULA Kategorii',
    'eula_text_help'					=> 'To pole pozwala dostosować EULA dla określonych rodzajów aktywów. Jeśli masz tylko jedno EULA dla wszystkich aktywów, można zaznaczyć poniższe pole, aby korzystać z domyślnej.',
    'name'                              => 'Nazwa Kategorii',
    'require_acceptance'				=> 'Wymaga od użytkowników, aby potwierdzić akceptację aktywów w tej kategorii.',
    'required_acceptance'				=> 'Do użytkownika zostanie wysłana wiadomość email z linkiem potwierdzającym akceptację przedmiotu.',
    'required_eula'						=> 'Do użytkownika zostanie wysłana wiadomość email z kopiąEULA',
    'no_default_eula'					=> 'Brak domyślnej EULA. Dodaj jakąś.',
    'update'  							=> 'Aktualizuj kategorię',
    'use_default_eula'					=> 'Użyj <a href="#" data-toggle="modal" data-target="#eulaModal"> domyślnej EULA</a> zamiast tego.',
    'use_default_eula_disabled'			=> '<del>Użyj domyślnej EULA.</del> Brak domyślnej EULA. Proszę dodaj jedną w Ustawieniach.',
    'use_default_eula_column'			=> 'Użyj domyślnej EULA',

);

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/pl-PL/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategorie aktywów',
    'category_name'  					=> 'Nazwa kategorii',
    'checkin_email'                     => 'Wyślij e-mail do użytkownika przy odbiorze / przypisaniu.',
    'email_to_initiator'                => 'Send email to you when user accepts or declines checkout.',
    'checkin_email_notification'        => 'Ten użytkownik otrzyma wiadomość e-mail o odbiorze / przypisaniu.',
    'clone'                             => 'Klonuj kategorię',
    'create'  							=> 'Stwórz Kategorię',
    'edit'                              => 'Edytuj Kategorię',
    'email_will_be_sent_due_to_global_eula' => 'Wiadomość e-mail zostanie wysłana do użytkownika, ponieważ jest używana licencja globalna.',
    'email_will_be_sent_due_to_category_eula' => 'Wiadomość e-mail zostanie wysłana do użytkownika, ponieważ dla tej kategorii jest ustawiona licencja.',
    'eula_text'							=> 'EULA Kategorii',
    'eula_text_help'					=> 'To pole pozwala dostosować EULA dla określonych rodzajów aktywów. Jeśli masz tylko jedno EULA dla wszystkich aktywów, można zaznaczyć poniższe pole, aby korzystać z domyślnej.',
    'name'                              => 'Nazwa Kategorii',
    'require_acceptance'				=> 'Wymaga od użytkowników, aby potwierdzić akceptację aktywów w tej kategorii.',
    'required_acceptance'				=> 'Do użytkownika zostanie wysłana wiadomość email z linkiem potwierdzającym akceptację przedmiotu.',
    'required_eula'						=> 'Do użytkownika zostanie wysłana wiadomość email z kopiąEULA',
    'no_default_eula'					=> 'Brak domyślnej EULA. Dodaj jakąś.',
    'update'  							=> 'Aktualizuj kategorię',
    'use_default_eula'					=> 'Użyj <a href="#" data-toggle="modal" data-target="#eulaModal"> domyślnej EULA</a> zamiast tego.',
    'use_default_eula_disabled'			=> '<del>Użyj domyślnej EULA.</del> Brak domyślnej EULA. Proszę dodaj jedną w Ustawieniach.',
    'use_default_eula_column'			=> 'Użyj domyślnej EULA',
    'import_require_acceptance'         => 'Require Acceptance',
    'import_checkin_email'              => 'Send Checkin Email',
    'import_eula_text'                  => 'EULA text',
    'import_category_type'              => 'Typ kategorii',

);
